@@ -9,7 +9,7 @@ from scipy.interpolate import UnivariateSpline, interp1d, InterpolatedUnivariate
 from aug_sfutils import cocos
 
 logger = logging.getLogger('aug_sfutils.mapeq')
-logger.setLevel(logging.DEBUG)
+logger.setLevel(logging.INFO)
 
 
 def get_nearest_index(tim_eq, tarr):
