@@ -10,6 +10,9 @@ libsfh = ct.cdll.LoadLibrary(sfhlib)
 
 logger = logging.getLogger('aug_sfutils.sfh')
 
+for key, val in sfdics.typ2descr.items():
+    exec('%s=%d' %(val, key))
+
 
 class SFH:
 
@@ -111,7 +114,7 @@ class SFH:
 
         dfmt = self.sf_header(pss)[pn].data_format
         if dfmt in sfdics.fmt2len.keys():
-            sf_dtype = 6
+            sf_dtype = CHAR
         else:
             sf_dtype = sfdics.fmt2typ[dfmt]
         pnlen = len(dat)
