@@ -10,6 +10,16 @@ logger = logging.getLogger('aug_sfutils.sfread')
 date_fmt = '%Y-%m-%d'
 logger.setLevel(logging.INFO)
 
+for key, val in sfdics.obj_name.items():
+    exec('%s=%d' %(val, key))
+for key, val in sfdics.cal_type.items():
+    exec('%s=%d' %(val, key))
+for key, val in sfdics.fmt2descr.items():
+    exec('%s=%d' %(val, key))
+for key, val in sfdics.tbtype_d.items():
+    exec('%s=%d' %(val, key))
+
+
 def read_other_sf(*args, **kwargs):
 
     return SFREAD(*args, **kwargs)
@@ -151,8 +161,8 @@ class SFREAD:
             return
 
         logger.info('Fetching SF %s', self.sfile)
-        self.objects = [ lbl for lbl, sfo in self.sfh.items() if sfo.obj_type in [6, 7, 8, 13] ]
-        self.parsets = [ lbl for lbl, sfo in self.sfh.items() if sfo.obj_type in [3, 4] ]
+        self.objects = [ lbl for lbl, sfo in self.sfh.items() if sfo.obj_type in [SignalGroup, Signal, TimeBase, AreaBase] ]
+        self.parsets = [ lbl for lbl, sfo in self.sfh.items() if sfo.obj_type in [Device, ParamSet] ]
         if 'ADDRLEN' in self.sfh.keys():
             size_fac = sfdics.addrsizes[self.sfh['ADDRLEN'].addrlen]
             for obj in self.sfh.keys():
@@ -198,11 +208,11 @@ class SFREAD:
             return None
         sfo = self.sfh[obj]
         otyp = sfo.obj_type
-        if otyp == 8:
+        if otyp == TimeBase:
             return self.getobject(obj)
-        elif otyp in (6, 7, 13):
+        elif otyp in (SignalGroup, Signal, AreaBase):
             for rel in sfo.relations:
-                if self.sfh[rel].obj_type == 8:
+                if self.sfh[rel].obj_type == TimeBase:
                     return self.getobject(rel)
         return None
 
@@ -218,15 +228,15 @@ class SFREAD:
             return None
         sfo = self.sfh[obj]
         otyp = sfo.obj_type
-        if otyp == 13:
+        if otyp == AreaBase:
             return self.getobject(obj)
-        elif otyp in (6, 7):
+        elif otyp in (SignalGroup, Signal):
             for rel in sfo.relations:
-                if self.sfh[rel].obj_type == 13:
+                if self.sfh[rel].obj_type == AreaBase:
                     return self.getobject(rel)
         return None
 
-    def getobject(self, obj, cal=False, copy=False, nbeg=None, nend=None):
+    def getobject(self, obj, cal=False, nbeg=None, nend=None):
         """
         Reads the data of a given TB, AB, SIG or SGR
         """
@@ -245,11 +255,11 @@ class SFREAD:
             logger.error('Status of SF object %s is %d' %(obj, sfo.status))
             return None
         otyp = sfo.obj_type
-        if otyp in (6, 7):
+        if otyp in (SignalGroup, Signal):
             shape_arr = np.array(sfo.index[::-1][:sfo.num_dims])
-        elif otyp == 8:
+        elif otyp == TimeBase:
             shape_arr = np.array([sfo.n_steps])
-        elif otyp == 13:
+        elif otyp == AreaBase:
             x = np.array([sfo.size_x, sfo.size_y, sfo.size_z, sfo.n_steps])
             shape_arr = x[x != 0]
         else:
@@ -258,8 +268,8 @@ class SFREAD:
 
         dfmt = sfo.data_format
         logger.debug('TB %s %d %d %d', obj, otyp, sfo.length, dfmt)
-        if otyp == 8 and sfo.length == 0:
-            if sfo.tbase_type == 1: # PPG_prog, e.g. END:T-LM_END
+        if otyp == TimeBase and sfo.length == 0:
+            if sfo.tbase_type == PPG_prog: # e.g. END:T-LM_END
                 data = self.ppg_time(obj)
             else:   # ADC_intern, e.g. DCN:T-ADC-SL
                 data = (np.arange(sfo.n_steps, dtype=np.float32) - sfo.n_pre)/sfo.s_rate
@@ -274,7 +284,7 @@ class SFREAD:
                 type_len = np.dtype(sfmt).itemsize
                 addr = sfo.address
                 bytlen = np.prod(shape_arr) * type_len
-                if otyp in (7, 8) or self.time_last(obj):
+                if otyp in (Signal, TimeBase) or self.time_last(obj):
                     if nbeg is None:
                         nbeg = 0
                     else:
@@ -288,7 +298,7 @@ class SFREAD:
                 data = np.ndarray(shape_arr, '>%s' %sfmt, self.getchunk(addr, bytlen), order='F')
 
 # LongLong in [ns] and no zero at TS06
-            if otyp == 8 and dfmt == 13: # RMC:TIME-AD0, SXS:Time
+            if otyp == TimeBase and dfmt == LONGLONG: # RMC:TIME-AD0, SXS:Time
                 logger.debug('Before getts06 dfmt:%d addr:%d len:%d data1:%d, %d', dfmt, addr, bytlen, data[0], data[1])
                 data = 1e-9*(data - self.getts06(obj))
                 logger.debug('%d',  self.getts06(obj))
@@ -296,13 +306,11 @@ class SFREAD:
             dout = sfobj.SFOBJ(data, sfho=sfo) # Add metadata
             dout.calib = False
 # Calibrated signals and signal groups
-            if otyp in (6, 7):
+            if otyp in (SignalGroup, Signal):
                 if cal:
                     dout = self.raw2calib(dout)
                     if self.diag in ('DCN', 'DCK', 'DCR'):
                         dout.phys_unit = '1/m^2'
-            if copy and (not dout.calib):
-                dout = dout.copy() # create a copy of the read-only array
 
         return dout
 
@@ -313,7 +321,7 @@ class SFREAD:
         """
 
         for rel in self.sfh[tbobj].relations:
-            if self.sfh[rel].obj_type == 3:
+            if self.sfh[rel].obj_type == Device:
                 ppg = self.getdevice(rel)
                 npt = self.sfh[tbobj].n_pre
                 nsteps = self.sfh[tbobj].n_steps
@@ -352,7 +360,7 @@ class SFREAD:
 
 # Calibrated signals and signal groups
         obj = str_byt.to_str(data.objnam)
-        if data.obj_type not in (6, 7):
+        if data.obj_type not in (SignalGroup, Signal):
             logging.error('Calibration failed for %s: no Sig, no SGR', obj)
             return data
 
@@ -371,7 +379,7 @@ class SFREAD:
                     dout.calib = True
                 multi = np.atleast_1d(pscal[mult])
                 shift = np.atleast_1d(pscal[shif])
-                if data.obj_type == 7 or len(multi) == 1:
+                if data.obj_type == Signal or len(multi) == 1:
                     dout *= multi[0] # MXR
                     dout += shift[0]
                 else:
@@ -398,12 +406,12 @@ class SFREAD:
         """
         obj = str_byt.to_str(obj)
         for rel in self.sfh[obj].relations:
-            if self.sfh[rel].obj_type == 4:
-                caltyp = str_byt.to_str(sfdics.cal_type[self.sfh[rel].cal_type])
-                if caltyp == 'LinCalib':
+            if self.sfh[rel].obj_type == ParamSet:
+                caltyp = self.sfh[rel].cal_type
+                if caltyp == LinCalib:
                     logger.info('PSet for calib: %s' %rel)
                     return self.getparset(rel)
-                elif caltyp == 'extCalib':
+                elif caltyp == extCalib:
                     diag_ext = self.getparset(rel)['DIAGNAME']
                     diag_ext = ''.join([str_byt.to_str(x) for x in diag_ext])
                     shot_ext = libddc.previousshot(diag_ext)
@@ -420,7 +428,7 @@ class SFREAD:
         pset = str_byt.to_str(pset)
         sfo = self.sfh[pset]
         otyp = sfo.obj_type
-        if otyp not in (3, 4):
+        if otyp not in (Device, ParamSet):
             return None
 
         buf = self.getchunk(sfo.address, sfo.length)
@@ -478,7 +486,7 @@ class SFREAD:
         sfo = self.sfh[obj]
         otyp = sfo.obj_type
         dfmt = sfo.data_format
-        if otyp != 2:
+        if otyp != List:
             return None
         buf = self.getchunk(sfo.address, sfo.length)
         sfmt = sfdics.fmt2struc[dfmt]
@@ -487,7 +495,7 @@ class SFREAD:
         return [self.getobjname(jid) for jid in list_ids]
 
 
-    def getlist_by_type(self, obj_type=7):
+    def getlist_by_type(self, obj_type=Signal):
 
         return [lbl for lbl, sfo in self.sfh.items() if sfo.obj_type == obj_type]
 
@@ -514,7 +522,7 @@ class SFREAD:
 # Look anywhere in the diagsnostic's Devices
         t606 = None
         for obj in self.parsets:
-            if self.sfh[obj].obj_type == 3:
+            if self.sfh[obj].obj_type == Device:
                 ps = self.getparset(obj)
                 if 'TS06' in ps.keys():
                     ts6 = ps['TS06']
@@ -529,11 +537,11 @@ class SFREAD:
         Reads the diagnostic internal TS06 from parameter set
         """
         ts06 = None
-        if self.sfh[obj].obj_type == 8:
+        if self.sfh[obj].obj_type == TimeBase:
             tb = obj
         else:
             for rel_obj in self.sfh[obj].relations:
-                if self.sfh[rel_obj].obj_type == 8: # related TB
+                if self.sfh[rel_obj].obj_type == TimeBase: # related TB
                     tb = rel_obj
                     break
         if 'tb' in locals(): # No TB related
@@ -542,7 +550,7 @@ class SFREAD:
             obj2 = obj
 
         for rel_obj in self.sfh[obj2].relations:
-            if self.sfh[rel_obj].obj_type == 3: # related device
+            if self.sfh[rel_obj].obj_type == Device: # related device
                 ps = self.getparset(rel_obj)
                 if 'TS06' in ps.keys():
                     ts6 = ps['TS06']
@@ -567,11 +575,11 @@ class SFREAD:
         obj = str_byt.to_str(obj)
         sfo = self.sfh[obj]
         otyp = sfo.obj_type
-        if otyp != 6:
+        if otyp != SignalGroup:
             return False # Objects other than sig, sgr, tbase
 
         for rel in sfo.relations:
-            if self.sfh[rel].obj_type == 8:
+            if self.sfh[rel].obj_type == TimeBase:
                 shape_arr = np.array(sfo.index[::-1][:sfo.num_dims])
                 nt = self.sfh[rel].n_steps
                 if shape_arr[0] != nt:
@@ -591,11 +599,11 @@ class SFREAD:
         obj = str_byt.to_str(obj)
         sfo = self.sfh[obj]
         otyp = sfo.obj_type
-        if otyp != 6:
+        if otyp != SignalGroup:
             return False # Objects other than sig, sgr, tbase
 
         for rel in sfo.relations:
-            if self.sfh[rel].obj_type == 8:
+            if self.sfh[rel].obj_type == TimeBase:
                 shape_arr = np.array(sfo.index[::-1][:sfo.num_dims])
                 nt = self.sfh[rel].n_steps
                 if shape_arr[-1] != nt:
