@@ -12,6 +12,12 @@ if not os.path.isfile(wwlib):
     wwlib = '/afs/ipp-garching.mpg.de/aug/ads/lib64/amd64_sles11/libddww8.so.8.1'
 libddww = ct.cdll.LoadLibrary(wwlib)
 
+for key, val in sfdics.obj_name.items():
+    exec('%s=%d' %(val, key))
+for key, val in sfdics.typ2descr.items():
+    exec('%s=%d' %(val, key))
+
+
 def getError(error):
 
     """ Check if an error/warning occured
@@ -21,8 +27,8 @@ def getError(error):
         err = ct.c_int32(error)
     except TypeError:
         err = ct.c_int32(error.value)
-    isError = libddww.xxsev_(ct.byref(err))==1
-    isWarning = libddww.xxwarn_(ct.byref(err))==1
+    isError = libddww.xxsev_(ct.byref(err)) == 1
+    isWarning = libddww.xxwarn_(ct.byref(err)) == 1
     if isError or isWarning:
         id = ct.c_char_p(b'')
         lid = ct.c_uint64(0)
@@ -166,11 +172,11 @@ class WW:
         if hasattr(self, '_diaref'):
             info  = self._wwoinfo(signame)
             otype = info['otype']
-            if otype in (7, 8):
+            if otype in (Signal, TimeBase):
                 self.SetSignal(signame, data)
-            elif otype == 6:
+            elif otype == SignalGroup:
                 self.SetSignalGroup(signame, data)
-            elif otype == 13:
+            elif otype == AreaBase:
                 self.SetAreabase(signame, data)
 
 
@@ -186,7 +192,7 @@ class WW:
             if dfmt in sfdics.fmt2len.keys():
                 lbuf = sfdics.fmt2len[dfmt]
                 lsbuf = ct.c_uint64(lbuf)
-                sf_dtype = 6
+                sf_dtype = CHAR
             else:
                 lbuf = np.size(data)
                 sf_dtype = sfdics.fmt2typ[dfmt]
@@ -223,11 +229,11 @@ class WW:
                 _lbuf = ct.byref(lbuf)
                 lsbuf = ct.c_uint64(len(sbuf)) 
                 buffer = ct.c_char_p(sbuf)
-                if otype == 7:   # Signal
+                if otype == Signal:
                     result = libddww.wwsignal_( \
                              _error, self._diaref, name, _type, _lbuf, buffer, \
                              _stride, lname, lsbuf)
-                elif otype == 6: # Signalgroup
+                elif otype == Signalgroup:
                     result = libddww.wwinsert_( \
                              _error, self._diaref, name, _type, _lbuf, buffer, \
                              _stride, _indices, lname, lsbuf)
@@ -235,23 +241,23 @@ class WW:
                 ctyp = sfdics.fmt2ct[dfmt]
                 data = np.atleast_1d(data)
                 data = np.array(data, dtype=sfdics.fmt2np[dfmt])
-                if otype == 7:   # Signal
+                if otype == Signal:
                     result = libddww.wwsignal_( \
                              _error, self._diaref, name, _type, _lbuf, \
                              data.ctypes.data_as(ct.POINTER(ctyp)), \
                              _stride, lname)
-                elif otype == 8: # Timebase
+                elif otype == Timebase:
                     result = libddww.wwtbase_( \
                              _error, self._diaref, name, _type, _lbuf, \
                              data.ctypes.data_as(ct.POINTER(ctyp)), \
                              _stride, lname)
-                elif otype == 6: #Signalgroup
+                elif otype == Signalgroup:
                     result = libddww.wwinsert_( \
                              _error, self._diaref, name, _type, _lbuf, \
                              data.ctypes.data_as(ct.POINTER(ctyp)), \
                              _stride, _indices, lname)
 
-            if otype in (7, 8):
+            if otype in (Signal, TimeBase):
                 sign = signame.decode('utf8')
                 if getError( error ):
                     raise Exception('ww: Error Writing %s %s' %(lbl, sign) )
@@ -347,7 +353,7 @@ class WW:
             info = self.GetParameterInfo(set_name, par_name)
             dfmt = info['format']
             if dfmt in sfdics.fmt2len.keys():
-                sf_dtype = 6
+                sf_dtype = CHAR
             else:
                 sf_dtype = sfdics.fmt2typ[dfmt]
             set_name = str_byt.to_byt(set_name)
@@ -398,7 +404,7 @@ class WW:
                 _stride = ct.byref(stride)
                 lbuf = ct.c_uint32(nitem)
                 _lbuf = ct.byref(lbuf)
-                if nitem == 1 and sf_dtype == 5:
+                if nitem == 1 and sf_dtype == LOGICAL:
                     buffer = ctyp(datanp)
                 else:
                     buffer = ctyp.from_buffer(datanp)
@@ -445,19 +451,19 @@ def write_sf(nshot, data_d, sfhdir, diag, exp='AUGD'):
     for obj, data in data_d.items():
         logger.debug(obj)
         otype[obj] = ww._wwoinfo(obj)['otype']
-        if otype[obj] == 8:
+        if otype[obj] == TimeBase:
             ww.SetObject(obj, data)
 
     for obj, data in data_d.items():
-        if otype[obj] == 13:
+        if otype[obj] == AreaBase:
             ww.SetObject(obj, data)
 
     for obj, data in data_d.items():
-        if otype[obj] == 4:
+        if otype[obj] == ParamSet:
             logger.info('Writing PS %s', obj)
             for pn, pdata in data.items():
                 ww.SetParameter(obj, pn, pdata)
-        if otype[obj] in (6, 7):
+        if otype[obj] in (Signal, SignalGroup):
             ww.SetObject(obj, data)
 
     ww.Close()
